gracetools.detach_grace_containers_attached_to_leaves_in_expr
=============================================================

.. autofunction:: abjad.tools.gracetools.detach_grace_containers_attached_to_leaves_in_expr.detach_grace_containers_attached_to_leaves_in_expr
   :noindex:
